@@ -3,6 +3,7 @@ foreground      = 'white'
 background      = 'black'
 fieldbackground = 'grey30'
 focusbackground = 'grey'
+insertbackground= 'white'
 
 selected        = 'green2'
 
@@ -11,6 +12,7 @@ disabled        = 'grey40'
 
 entry_grey      = 'grey45'
 entry_white     = 'grey92'
+entry_disabled      = 'black'
 
 tab             = 'grey'
 
